import 'package:flutter/material.dart';
import '../marker_handler/marker_data.dart';
import '../consts.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:latlong2/latlong.dart';
import 'package:fl_chart/fl_chart.dart';
import 'quick_view_chart.dart';
import 'stat_charts.dart';

class MapContainerWidget extends StatefulWidget {
  final List<Measurement> markerList;

  const MapContainerWidget({Key? key, required this.markerList}) : super(key: key);

  @override
  _MapContainerWidgetState createState() => _MapContainerWidgetState();
}

class _MapContainerWidgetState extends State<MapContainerWidget> {

  Measurement? selectedMarker;
  bool isMinimized = true; // Quick view box state tacker

  @override
  Widget build(BuildContext context) {

    const double contPadding = 30; // Container padding space

    return LayoutBuilder(
      builder: (context, constraints) {
        double screenWidth = constraints.maxWidth;
        double boxWidth = 0.86;
        double boxHeight = 1.4;
        return Column(
          children: [
            const SizedBox(height: contPadding),
            ClipRRect(
              borderRadius: BorderRadius.circular(20),
              child: Stack( // Stack quick view on top of map
                children: [
                  SizedBox(
                    width: screenWidth * boxWidth,
                    height: screenWidth * boxHeight,
                    child: FlutterMap(
                      options: MapOptions(
                        center: mapCenter, // From consts
                        zoom: 9.0,
                      ),
                      children: [
                        TileLayer( // Map from OpenStreetMap
                          urlTemplate: "https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png",
                          subdomains: const ['a', 'b', 'c'],
                        ),
                        PolygonLayer( // Map each element in markerList to Measurement object
                          polygons: widget.markerList.map((Measurement measurement) {
                            return Polygon(
                              points: measurement.cornerList.map((Corner corner) {
                                // Map corners to LatLng objects
                                return LatLng(corner.latitude, corner.longitude);
                              }).toList(),
                              /*onTap: () {
                                setState(() {
                                  selectedMarker = measurement;
                                });
                              },*/
                              color: Colors.blue,
                              isFilled: true,
                            );
                          }).toList(),
                        )
                      ],
                    ),
                  ),
                  Positioned( // Quick view box layered over map
                    bottom: 10,
                    right: 10,
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(10),
                      child: Container(
                        width: (screenWidth * boxWidth) / 2.4,
                        height: isMinimized ? 20 : (screenWidth * boxWidth) / 2.4,
                        color: Colors.blue.withOpacity(0.7),
                        child: Stack(
                          children: [
                            Visibility( // Content only visible when box is maximized
                              visible: !isMinimized && selectedMarker != null,
                              child: Center(
                                child: Padding(
                                  padding: const EdgeInsets.only(right: 16.0, top: 17.0),
                                  child: SizedBox(
                                    width: (screenWidth * boxWidth) / 2.3,
                                    height: (screenWidth * boxWidth) / 2.3,
                                    child: const QuickViewChart(),
                                  ),
                                ),
                              ),
                            ),
                            Positioned(
                              top: 0,
                              right: 5,
                              child: GestureDetector(
                                onTap: () {
                                  setState(() {
                                    isMinimized = !isMinimized; // Toggle minimized state
                                  });
                                },
                                child: Icon(isMinimized ? Icons.arrow_drop_up : Icons.arrow_drop_down),
                              ),
                            ),
                          ],
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
            const SizedBox(height: contPadding), // Padding between containers
            ClipRRect(
              borderRadius: BorderRadius.circular(20),
              child: Container(
                width: screenWidth * boxWidth,
                height: screenWidth * boxHeight * 1.5, // NB: make dynamic
                child: Align(
                  alignment: Alignment.topLeft,
                  child: Padding(
                    padding: const EdgeInsets.only(top: 20, left: 20), // Edge padding, text
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                         Text(
                          'Ice stats',
                          style: titleStyle,
                        ),
                        Text(
                          'Time of measurement: ${selectedMarker?.timeMeasured}',
                          style: regTextStyle,
                        ),
                        Text(
                          'Location: (placeholder, placeholder)',
                          style: regTextStyle,
                        ),
                        const SizedBox(height: contPadding),
                        const StatCharts(),
                      ],
                    ),
                  ),
                ),
              ),
            ),
          ],
        );
      },
    );
  }
}